@@ -1,10 +1,9 @@
 #' Map a plan position indicator (`ppi`) on a map
 #'
-#' Plots a plan position indicator (`ppi`) on a base layer using
-#' [ggmap::ggmap()].
+#' Plots a plan position indicator (`ppi`) on a base layer
 #'
 #' @param x A `ppi` object.
-#' @param map Basemap to use, result of a call to [download_basemap()].
+#' @param map Basemap to use, one of `rosm::osm.types()`
 #' @param param Character. Scan parameter to plot, e.g. `DBZH` or `VRADH`. See
 #'   [summary.param()] for commonly available parameters.
 #' @param alpha Numeric. Transparency of the data, value between 0 and 1.
@@ -21,11 +20,9 @@
 #' @param n_color Numeric. Number of colors (>=1) to use in the palette.
 #' @param palette Character vector. Hexadecimal color values defining the plot
 #'   color scale, e.g. output from [viridisLite::viridis()].
-#' @param ... Arguments passed to [ggmap::ggmap()].
+#' @param ... Arguments passed to [ggplot2::ggplot()].
 #' @importFrom methods as
-#' @return A ggmap object (a classed raster object with a bounding
-#' box attribute).
-#'
+#' @return A ggplot object
 #' @details
 #' Available scan parameters for mapping can by printed to screen by
 #' `summary(x)`. Commonly available parameters are:
@@ -44,15 +41,14 @@
 #' @export
 #'
 #' @seealso
-#' * [download_basemap()]
 #' * [project_as_ppi()]
 #'
 #' @examples
 #' # Project a scan as a ppi
 #' ppi <- project_as_ppi(example_scan)
 #' \donttest{
-#' # Create a basemap that matches the extent of the ppi
-#' basemap <- download_basemap(ppi, maptype = "toner-lite")
+#' # Choose a basemap
+#' basemap <- rosm::osm.types()[1]
 #'
 #' # Map the radial velocity of the ppi onto the basemap
 #' map(ppi, map = basemap, param = "VRADH")
@@ -81,8 +77,8 @@ map <- function(x, ...) {
 
 #' @describeIn map Plot a `ppi` object on a map.
 #' @export
-map.ppi <- function(x, map, param, alpha = 0.7, xlim, ylim, zlim = c(-20, 20),
-                    ratio, radar_size = 3, radar_color = "red", n_color = 1000,
+map.ppi <- function(x, map="cartolight", param, alpha = 0.7, xlim, ylim, zlim = c(-20, 20),
+                    ratio, radar_size = 3, radar_color = "#202020", n_color = 1000,
                     palette = NA, ...) {
 
   stopifnot(inherits(x, "ppi"))
@@ -110,14 +106,19 @@ map.ppi <- function(x, map, param, alpha = 0.7, xlim, ylim, zlim = c(-20, 20),
   if (is.na(raster::crs(x$data))) {
     stop("Not a projected ppi, map() expects a ppi generated by project_as_ppi() with argument project=TRUE")
   }
-  if (!attributes(map)$ppi) {
-    stop("Not a ppi map, use download_basemap() to download a map.")
-  }
-  if (all(attributes(map)$geo$lat != x$geo$lat) ||
-    all(attributes(map)$geo$lon != x$geo$lon)) {
-    stop("Not a basemap for this radar location.")
+
+  # check that suggested dependencies are presetn
+  rlang::check_installed(c("ggspatial","prettymapr"),'to map ppi\'s')
+
+  assert_valid_basemap <- function(basemap) {
+    valid_types <- rosm::osm.types()
+    if (!(basemap %in% valid_types)) {
+      stop(paste("Invalid basemap argument. Must be one of:", paste(valid_types, collapse=", ")))
+    }
   }
 
+  assert_valid_basemap(map)
+
   # set color scales and palettes
   if (!assertthat::are_equal(palette, NA)) {
     if(!(is.character(palette) && length(palette) > 1)) stop("palette should be a character vector with hex color values")
@@ -188,44 +189,50 @@ map.ppi <- function(x, map, param, alpha = 0.7, xlim, ylim, zlim = c(-20, 20),
   }
 
   # convert data values to hex color string values.
-  r@data@values <- col_func(r@data@values, zlim)
+
+  rdf <- raster::as.data.frame(r, xy = TRUE)
+  names(rdf) <- c("x", "y", "fill")
+  rdf$fill <- col_func(r@data@values, zlim)
 
   # these declarations prevent generation of NOTE "no visible binding for
   # global variable" during package Check
-  lon <- lat <- y <- z <- NA
+  fill <- lon <- lat <- X <- Y <- y <- z <- NA
   # extract unique radar locations
-  latlon_radar <- unique(data.frame(lat=c(x$geo$lat), lon=c(x$geo$lon)))
-  # symbols for the radar position
+
   # dummy is a hack to be able to include the ggplot2 color scale,
   # radarpoint is the actual plotting of radar positions.
+
+  radar_location = data.frame(lon = x$geo$lon, lat = x$geo$lat) %>%
+    sf::st_as_sf(coords = c("lon", "lat"))  %>%
+    sf::st_set_crs(4326)  %>%
+    sf::st_transform(3857)
+
+  radar_df <- data.frame(sf::st_coordinates(radar_location))
+
   dummy <- ggplot2::geom_point(ggplot2::aes(x = lon, y = lat, colour = z),
-    size = 0,
-    data = data.frame(
-      lon = latlon_radar$lon,
-      lat = latlon_radar$lat,
-      z = 0
-    )
-  )
-  radarpoint <- ggplot2::geom_point(ggplot2::aes(x = lon, y = lat),
-    colour = radar_color,
-    size = radar_size,
-    data = data.frame(lon = latlon_radar$lon, lat = latlon_radar$lat)
-  )
-  # bounding box
-  bboxlatlon <- attributes(map)$geo$bbox
-  # remove dimnames, otherwise ggmap will give a warning message below:
-  dimnames(bboxlatlon) <- NULL
-  if (missing(xlim)) xlim <- bboxlatlon[1, ]
-  if (missing(ylim)) ylim <- bboxlatlon[2, ]
-  # plot the data on the map
-  rlang::check_installed("ggmap",'to map ppi\'s', version = '3.0.0')
-  mymap <- suppressMessages(
-    ggmap::ggmap(map) +
-      ggmap::inset_raster(raster::as.matrix(r), e@xmin, e@xmax, e@ymin, e@ymax) +
-      dummy + colorscale +
-      radarpoint +
-      ggplot2::scale_x_continuous(limits = xlim, expand = c(0, 0)) +
-      ggplot2::scale_y_continuous(limits = ylim, expand = c(0, 0))
+                               size = 0,
+                               data = data.frame(
+                                 lon = radar_df$X,
+                                 lat = radar_df$Y,
+                                 z = 0
+                               ))
+
+  mymap <- suppressWarnings(
+    ggplot2::ggplot() +
+      ggspatial::annotation_map_tile(type = map) +
+      ggplot2::geom_raster(data = rdf, ggplot2::aes(x = x, y = y, fill = fill), na.rm = TRUE, interpolate = FALSE) +
+      ggplot2::scale_fill_identity(na.value = "transparent") +
+      ggplot2::geom_point(data = radar_df, ggplot2::aes(x = X, y = Y),
+                 shape = 21,
+                 fill = "transparent",
+                 colour = radar_color,
+                 size = radar_size,
+                 stroke = 1.5,
+                 show.legend = FALSE) +
+      dummy +
+      colorscale +
+      ggplot2::labs(x="lon", y="lat")
   )
+
   suppressWarnings(mymap)
 }
