@@ -31,11 +31,6 @@ test_that("plot.vpi() returns error on incorrect parameters", {
   )
 })
 
-test_that("plot.vpi() warns for deprecated arguments", {
-  expect_warning(plot(example_vpi, line.col = "red"))
-  expect_warning(plot(example_vpi, line.lwd = 1))
-})
-
 test_that("plot.vpi() produces plots", {
   expect_s3_class(recordPlot(plot(example_vpi)), "recordedplot")
   expect_s3_class(recordPlot(plot(example_vpi, quantity = "vir")), "recordedplot")
